@@ -11,8 +11,8 @@ from delphai_utils.gateway import start_gateway
 from delphai_utils.keycloak import update_public_keys
 from prometheus_client import start_http_server
 
-from interceptors.metrics import MetricsInterceptor
-from interceptors.authentication import AuthenticationInterceptor
+from delphai_utils.interceptors.metrics import MetricsInterceptor
+from delphai_utils.interceptors.authentication import AuthenticationInterceptor
 shutdown_event = asyncio.Event()
 
 
